@@ -29,9 +29,9 @@ from runestone.common.runestonedirective import add_i18n_js
 def setup(app):
     app.add_directive('fillintheblank', FillInTheBlank)
     app.add_role('blank', BlankRole)
-    app.add_stylesheet('fitb.css')
-    app.add_javascript('fitb.js')
-    app.add_javascript('timedfitb.js')
+    app.add_css_file('fitb.css')
+    app.add_js_file('fitb.js')
+    app.add_js_file('timedfitb.js')
     add_i18n_js(app, {"en","sr","sr-Latn","sr-Cyrl"}, "fitb-i18n")
     app.add_node(FITBNode, html=(visit_fitb_node, depart_fitb_node))
     app.add_node(BlankNode, html=(visit_blank_node, depart_blank_node))
